# How to use the Web app

To run XspecT in a web browser, you can use the following command:

```bash
xspect web
```
This will start a web server running on port 8000. You can access the web app by navigating to [http://localhost:8000](http://localhost:8000) in your web browser.

## Web App Features

Within the web app, you can perform the following tasks:

- Upload samples for classification
- Submit samples for classification and view results
- Submit samples for filtering and view results
- Manage models
